[cig-commits] [commit] doc_updates: Function name changed to lowercase (d8c79b2)

cig_noreply at geodynamics.org cig_noreply at geodynamics.org
Tue Dec 30 15:35:22 PST 2014


Repository : https://github.com/geodynamics/burnman

On branch  : doc_updates
Link       : https://github.com/geodynamics/burnman/compare/0f29d91785755799fda918fb6e9685e0c09bc757...d8c79b2ac291869fba395b365ae54da64b676ac0

>---------------------------------------------------------------

commit d8c79b2ac291869fba395b365ae54da64b676ac0
Author: Bob Myhill <myhill.bob at gmail.com>
Date:   Tue Dec 30 23:35:08 2014 +0000

    Function name changed to lowercase


>---------------------------------------------------------------

d8c79b2ac291869fba395b365ae54da64b676ac0
 burnman/processchemistry.py | 4 ++--
 burnman/solutionmodel.py    | 2 +-
 2 files changed, 3 insertions(+), 3 deletions(-)

diff --git a/burnman/solutionmodel.py b/burnman/solutionmodel.py
index 390cede..ac113db 100644
--- a/burnman/solutionmodel.py
+++ b/burnman/solutionmodel.py
@@ -122,7 +122,7 @@ class IdealSolution (SolutionModel):
 
         # Process solid solution chemistry
         self.solution_formulae, self.n_sites, self.sites, self.n_occupancies, self.endmember_occupancies, self.site_multiplicities = \
-            ProcessSolidSolutionChemistry(self.formulas)
+            process_solution_chemistry(self.formulas)
 
         self._calculate_endmember_configurational_entropies()
 



More information about the CIG-COMMITS mailing list
diff --git a/burnman/processchemistry.py b/burnman/processchemistry.py
index e4cb2d5..a64d10a 100644
--- a/burnman/processchemistry.py
+++ b/burnman/processchemistry.py
@@ -4,7 +4,7 @@
 
 # This module provides the functions required to process the standard burnman formula compositions
 # ProcessChemistry returns the number of atoms and molar mass of a compound given its unit formula as an argument.
 # ProcessSolidSolutionChemistry returns information required to calculate solid solution properties from a set of endmember formulae
 
 import re
 import numpy as np
@@ -95,7 +95,7 @@ def dictionarize_site_formula(formula):
     return f
 
 
-def ProcessSolidSolutionChemistry(formulae):
+def process_solution_chemistry(formulae):
     """
     This function parses a set of endmember formulae 
     containing site information, e.g.
@@ -4,7 +4,7 @@
 # This module provides the functions required to process the standard burnman formula compositions
 # ProcessChemistry returns the number of atoms and molar mass of a compound given its unit formula as an argument.
-# ProcessSolidSolutionChemistry returns information required to calculate solid solution properties from a set of endmember formulae
+# process_solution_chemistry returns information required to calculate solid solution properties from a set of endmember formulae
 
 import re